@@ -2,22 +2,30 @@ package HTML::FormFu::Constraint;
 
 use strict;
 use base 'HTML::FormFu::Processor';
-use mro 'c3';
+use Class::C3;
+use Moose;
+extends 'HTML::FormFu::Processor';
 
 use HTML::FormFu::Exception::Constraint;
 use HTML::FormFu::Util qw(
     DEBUG_CONSTRAINTS
     debug
 );
-use Carp qw( croak );
 use Clone ();
 use List::MoreUtils qw( any );
+use Scalar::Util qw( blessed );
+use Carp qw( croak );
+use Clone ();
+use List::MoreUtils qw( any all );
 use List::Util qw( first );
 use Scalar::Util qw( reftype blessed );
 
-__PACKAGE__->mk_accessors(qw( only_on_reps ));
+has not          => ( is => 'rw', traits  => ['Chained'] );
+has force_errors => ( is => 'rw', traits  => ['Chained'] );
+has when         => ( is => 'rw', traits  => ['Chained'] );
+has only_on_reps => ( is => 'rw', traits  => ['Chained'] );
 
-__PACKAGE__->mk_item_accessors(qw( not force_errors when ));
+sub pre_process {}
 
 sub process {
     my ( $self, $params ) = @_;
@@ -172,7 +180,7 @@ sub _process_when {
 
     # returns 1 if when condition is fullfilled or not defined
     # returns 0 if when condition is defined and not fullfilled
-    # If it's a callback, return callback's return value (so when
+    # If it's a callback, return callback's return value (so 'when'
     # condition is met if callback returns a true value)
 
     # get when condition
@@ -183,20 +191,55 @@ sub _process_when {
     croak "Parameter 'when' is not a hash ref" if ref $when ne 'HASH';
 
     # field or callback must be defined
-    my $when_field    = $when->{field};
-    my $when_callback = $when->{callback};
-    croak "Parameter 'field' or 'callback' is not defined"
-        if !defined $when_field && !defined $when_callback;
+    my $when_field     = $when->{field};
+    my $when_fields    = $when->{fields};
+    my $when_any_field = $when->{any_field};
+    my $when_callback  = $when->{callback};
+    
+    croak "'field', 'fields', 'any_field' or 'callback' key must be defined in 'when'"
+        if all {!defined} $when_field, $when_fields, $when_any_field, $when_callback;
 
     # Callback will be the preferred thing
     if ($when_callback) {
         no strict 'refs';
         return $when_callback->($params);
     }
+    
+    my $any;
+    my @when_fields_value;
+    
+    if ($when_any_field) {
+        croak "'any_field' is set to an empty list" if !@$when_any_field;
 
-    # nothing to constrain if field doesn't exist
-    my $when_field_value = $self->get_nested_hash_value( $params, $when_field );
-    return 0 if !defined $when_field_value;
+        $any = 1;
+        
+        @$when_fields = @$when_any_field;
+    }
+    
+    if ($when_fields) {
+        croak "'fields' is set to an empty list" if !@$when_fields;
+        
+        for my $name (@$when_fields) {
+            my $value = $self->get_nested_hash_value( $params, $name );
+            
+            push @when_fields_value, $value
+                if defined $value;
+        }
+    }
+    else {
+        # nothing to constrain if field doesn't exist
+        my $value = $self->get_nested_hash_value( $params, $when_field );
+        
+        push @when_fields_value, $value
+            if defined $value;
+    }
+
+    DEBUG_CONSTRAINTS && debug('WHEN_FIELDS_VALUES' => \@when_fields_value);
+
+    if (!@when_fields_value) {
+        DEBUG_CONSTRAINTS && debug("No 'when' fields values exist - returning false");
+        return 0;
+    }
 
     my @values;
 
@@ -208,25 +251,34 @@ sub _process_when {
     }
 
     # determine if condition is fulfilled
-    my $ok;
+    my @ok;
 
     if (@values) {
-        $ok = any { $when_field_value eq $_ } @values;
+        for my $value (@when_fields_value) {
+            push @ok, any { $value eq $_ } @values;
+        }
     }
     else {
-        $ok = $when_field_value ? 1 : 0;
+        for my $value (@when_fields_value) {
+            push @ok, $value ? 1 : 0;
+        }
     }
+    
+    DEBUG_CONSTRAINTS && debug("'when' value matches" => \@ok);
 
-    # invert when condition if asked for
-    $ok = $when->{not} ? !$ok : $ok;
-
-    return $ok;
+    my $return = $any ? any { $when->{not} ? !$_ : $_ } @ok
+               :        all { $when->{not} ? !$_ : $_ } @ok
+               ;
+    
+    DEBUG_CONSTRAINTS && debug("'when' return value" => $return);
+    
+    return $return;
 }
 
 sub clone {
     my $self = shift;
 
-    my $clone = $self->next::method(@_);
+    my $clone = $self->SUPER::clone(@_);
 
     if ( defined( my $when = $self->when ) ) {
         $clone->when( Clone::clone $when );
@@ -235,6 +287,8 @@ sub clone {
     return $clone;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -383,7 +437,19 @@ The following keys are supported:
 
 =item field
 
-nested-name of form field that shall be checked against
+Nested-name of form field that shall be checked against - if C<when->{value}>
+is set, the C<when> condition passes if the named field's value matches that,
+otherwise the C<when> condition passes if the named field's value is true.
+
+=item fields
+
+Array-ref of nested-names that shall be checked. The C<when> condition passes
+if all named-fields' values pass, using the same rules as C<field> above.
+
+=item any_field
+
+Array-ref of nested-names that shall be checked. The C<when> condition passes
+if any named-fields' values pass, using the same rules as C<field> above.
 
 =item value
 
@@ -493,4 +559,4 @@ Sebastian Riedel, C<sri@oook.de>.
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
-=cut
+=cut
\ No newline at end of file
