@@ -1,12 +1,14 @@
 package HTML::FormFu::Constraint::ASCII;
 
-use strict;
-use base 'HTML::FormFu::Constraint::Regex';
+use Moose;
+extends 'HTML::FormFu::Constraint::Regex';
 
 sub regex {
     return qr/^\p{IsASCII}*\z/;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
