@@ -1,7 +1,7 @@
 package HTML::FormFu::Constraint::Number;
 
-use strict;
-use base 'HTML::FormFu::Constraint';
+use Moose;
+extends 'HTML::FormFu::Constraint';
 
 use Scalar::Util qw( looks_like_number );
 
@@ -15,6 +15,8 @@ sub constrain_value {
     return $self->not ? !$ok : $ok;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -41,3 +43,5 @@ Carl Franks C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
