@@ -1,18 +1,21 @@
 package HTML::FormFu::Element::File;
+use Moose;
 
-use strict;
-use base 'HTML::FormFu::Element::_Input';
-use mro 'c3';
+extends 'HTML::FormFu::Element';
 
-sub new {
-    my $self = shift->next::method(@_);
+with 'HTML::FormFu::Role::Element::Input';
+
+after BUILD => sub {
+    my $self = shift;
 
     $self->field_type('file');
 
     $self->form->enctype('multipart/form-data');
 
-    return $self;
-}
+    return;
+};
+
+__PACKAGE__->meta->make_immutable;
 
 1;
 
