@@ -1,8 +1,7 @@
 package HTML::FormFu::I18N;
-use strict;
-use warnings;
+use Moose;
 
-use base 'Locale::Maketext';
+extends 'Locale::Maketext';
 
 *loc = \&localize;
 
@@ -12,4 +11,6 @@ sub localize {
     return $self->maketext(@_);
 }
 
+__PACKAGE__->meta->make_immutable( inline_constructor => 0 );
+
 1;
