@@ -1,8 +1,7 @@
 package HTML::FormFu::Inflator;
 
-use strict;
-use base 'HTML::FormFu::Processor';
-use mro 'c3';
+use Moose;
+extends 'HTML::FormFu::Processor';
 
 use HTML::FormFu::Exception::Inflator;
 use Scalar::Util qw( blessed );
@@ -50,6 +49,8 @@ sub return_error {
     return $err;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
